/* 
 * $Id: CSVAnalyzer.h 20876 2009-04-12 20:04:59Z ozawa $
 *
 * Copyright 2005- ONGS Inc. All rights reserved.
 * 
 * author: Masanori OZAWA (ozawa@ongs.co.jp)
 * version: $Revision: 20876 $
 *
 * Redistribution and use in source and binary forms, with or without 
 * modification, are permitted provided that the following conditions
 * are met:
 * 
 *   1. Redistributions of source code must retain the above copyright
 *      notice, this list of conditions and the following disclaimer.
 *   2. Redistributions in binary form must reproduce the above copyright
 *      notice, this list of conditions and the following disclaimer in the
 *      documentation and/or other materials provided with the distribution.
 * 
 * THIS SOFTWARE IS PROVIDED BY ONGS INC ``AS IS'' AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL ONGS INC OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT,
 * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 * The views and conclusions contained in the software and documentation are
 * those of the authors and should not be interpreted as representing official
 * policies, either expressed or implied, of the ONGS Inc.
 * 
 */
 
#ifndef ___CSVANALYZER_H
#define ___CSVANALYZER_H

#include "xdtptypes.h"

namespace XDTP {

class CSVAnalyzer
{
public:
	CSVAnalyzer();
	virtual ~CSVAnalyzer();

    /**
     * CSV データを解析し、List データ構造に格納します。
     * 
     * @param aLine
     *            解析元のCSVデータ１行
     * @return List データ構造に格納した CSV データ
     */
    bool analyzeLine(const Glib::ustring& aLine, StringList& aList);
    
private:
    /**
     * 指定された場所以降で, 次に区切りのカンマが現れる場所を返します。
     * 次にカンマが見当たらない場合, 解析対象の文字列の長さが還ります。
     * ただし、データが妥当でない(たとえばダブルクォーテーションの囲いが
     * 終了していないのに行が終わっている場合)は -1 を返します。
     * 
     * @param aStartPoint
     *            解析開始位置
     * @param aLine
     *            解析元CSVデータ１行
     * @return 次に区切りのカンマが来る位置か, データの長さ。データが 妥当でない場合は -1 が返ります。
     */
    Glib::ustring::size_type nextCommaPoint
        (Glib::ustring::size_type aStartPoint, const Glib::ustring& aLine);
};

};

#endif
