/* 
 * $Id: URLTool.h 20876 2009-04-12 20:04:59Z ozawa $
 *
 * Copyright 2005- ONGS Inc. All rights reserved.
 * 
 * author: Masanori OZAWA (ozawa@ongs.co.jp)
 * version: $Revision: 20876 $
 *
 * Redistribution and use in source and binary forms, with or without 
 * modification, are permitted provided that the following conditions
 * are met:
 * 
 *   1. Redistributions of source code must retain the above copyright
 *      notice, this list of conditions and the following disclaimer.
 *   2. Redistributions in binary form must reproduce the above copyright
 *      notice, this list of conditions and the following disclaimer in the
 *      documentation and/or other materials provided with the distribution.
 * 
 * THIS SOFTWARE IS PROVIDED BY ONGS INC ``AS IS'' AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL ONGS INC OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT,
 * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 * The views and conclusions contained in the software and documentation are
 * those of the authors and should not be interpreted as representing official
 * policies, either expressed or implied, of the ONGS Inc.
 * 
 */

#ifndef ___URLTOOL_H
#define ___URLTOOL_H

#include "glibmm.h"

#include "RefPtr.h"

namespace XDTP {

typedef struct {
    int     width;
    int     height;
} IMAGE_INFO;

typedef struct {
    off_t   size;
    time_t  atime;
    time_t  mtime;
} FILE_INFO;

typedef enum {
    URL_FTP,
    URL_HTTP,   // include https
    URL_FILE,
    URL_UNKNOWN
} URLTYPE;

class URLTool
{
public:
	virtual ~URLTool();
    
public:
    /**
     * URLで参照するリソースを取得します。
     * 
     * @param url リソースを識別するURL
     * @param buf 取得したバッファへのアドレスを記録する。
     *            不要になった段階で free する必要があります。
     * @param len 取得したバッファのバイト長。
     * @return 成功した場合は true を戻す。
     */
    static bool getResource(const Glib::ustring& url, char** buf, int* len);
    
    /**
     * URLで参照するリソースを取得します。
     * 
     * @param url リソースを識別するURL
     * @param file 出力先ファイル名
     * @return 成功した場合は true を戻す。
     */
    static bool getResource2File(const Glib::ustring& url, const Glib::ustring& file);
    
    /**
     * URLで参照するリソースを取得します。
     * 
     * @param url リソースを識別するURL
     * @param fd 出力先ファイルディスクリプタ
     * @return 成功した場合は true を戻す。
     */
    static bool getResource2File(const Glib::ustring& url, int fd);
    
    /**
     * 画像情報のみを取得します。
     * 
     * @param url 画像を識別するURL
     * @param info 情報を格納する IMAGE_INFO 構造体
     * @return 取得に成功した場合は true を戻す。
     */
    static bool getImageInfo(const Glib::ustring& url, IMAGE_INFO& info);

    /**
     * リソースの情報を取得します。
     * サーバ側の応答コードを利用して情報を取得する場合があるため、
     * 実際とは異なる情報を取得する場合があります。
     * 
     * @param url リソースを識別するURL
     * @param info 情報を格納する FILE_INFO 構造体
     * @return 取得に成功した場合は true を戻す。
     */
    static bool statResource(const Glib::ustring& url, FILE_INFO& info);
    
protected:
    URLTool();

    virtual bool openResource(const Glib::ustring& url, URLTYPE type) = 0;
    virtual void closeResource(bool force = false) = 0;
    virtual int readResource(char* buf, int len) = 0;
    virtual bool statResourceCore(const Glib::ustring& url, FILE_INFO& info) = 0;

protected:
    static URLTYPE parseURLType(const Glib::ustring& url);

private:
    static RefPtr<URLTool> buildURLTool();
};

};

#endif
