/* 
 * $Id: Utilities.h 20876 2009-04-12 20:04:59Z ozawa $
 *
 * Copyright 2005- ONGS Inc. All rights reserved.
 * 
 * author: Masanori OZAWA (ozawa@ongs.co.jp)
 * version: $Revision: 20876 $
 *
 * Redistribution and use in source and binary forms, with or without 
 * modification, are permitted provided that the following conditions
 * are met:
 * 
 *   1. Redistributions of source code must retain the above copyright
 *      notice, this list of conditions and the following disclaimer.
 *   2. Redistributions in binary form must reproduce the above copyright
 *      notice, this list of conditions and the following disclaimer in the
 *      documentation and/or other materials provided with the distribution.
 * 
 * THIS SOFTWARE IS PROVIDED BY ONGS INC ``AS IS'' AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL ONGS INC OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT,
 * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 * The views and conclusions contained in the software and documentation are
 * those of the authors and should not be interpreted as representing official
 * policies, either expressed or implied, of the ONGS Inc.
 * 
 */

#ifndef ___UTILITIES_H
#define ___UTILITIES_H

#include "glibmm.h"

namespace XDTP {

class Utilities
{
public:
	virtual ~Utilities();
    
    /**
     * ファイルを複写します。
     */
    static bool copy(const Glib::ustring& in, const Glib::ustring& out);
    static bool copy(const Glib::ustring& in, int out);
    
    /**
     * ファイルを移動します。
     */
    static bool move(const Glib::ustring& in, const Glib::ustring& out);
    
    /**
     * ファイルを標準出力へ書き出します。
     */
    static bool printFile(const Glib::ustring& file);
    
    /**
     * 文字列の前後の空白を除去します。
     * 
     * @param szSrc 除去する前の文字列
     * @return 前後の空白を除去した文字列
     */
    static Glib::ustring strTrim(const Glib::ustring& szSrc);

    /**
     * 文字列の前の空白を除去します。
     * 
     * @param szSrc 除去する前の文字列
     * @return 前の空白を除去した文字列
     */
    static Glib::ustring strTrimLeft(const Glib::ustring& szSrc);

    /**
     * 文字列の後の空白を除去します。
     * 
     * @param szSrc 除去する前の文字列
     * @return 後の空白を除去した文字列
     */
    static Glib::ustring strTrimRight(const Glib::ustring& szSrc);
    
    /**
     * 文字列の終端にある改行コードを除去します。
     * 
     * @param szSrc 除去する前の文字列
     * @return 後の改行コードを除去した文字列
     */
    static Glib::ustring strTrimCRLF(const Glib::ustring& szSrc);
    
    /**
     * 指定の文字列を全て置換します。
     *
     * @param szSrc 元の文字列
     * @param szOld 置換対象の文字列
     * @param szNew 置き換える文字列
     */
    static Glib::ustring strReplaceAll(const Glib::ustring& szSrc,
                                        const Glib::ustring& szOld,
                                        const Glib::ustring& szNew);

private:
    Utilities();
};

};

#endif
