/*
 * $Id: XDTPObjectWrapper.h 20876 2009-04-12 20:04:59Z ozawa $
 *
 * Copyright 2005- ONGS Inc. All rights reserved.
 *
 * author: Masanori OZAWA (ozawa@ongs.co.jp)
 * version: $Revision: 20876 $
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 *   1. Redistributions of source code must retain the above copyright
 *      notice, this list of conditions and the following disclaimer.
 *   2. Redistributions in binary form must reproduce the above copyright
 *      notice, this list of conditions and the following disclaimer in the
 *      documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY ONGS INC ``AS IS'' AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL ONGS INC OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT,
 * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 * The views and conclusions contained in the software and documentation are
 * those of the authors and should not be interpreted as representing official
 * policies, either expressed or implied, of the ONGS Inc.
 *
 */

#ifndef ___XDTPOBJECTWRAPPER_H
#define ___XDTPOBJECTWRAPPER_H

#include "xdtptypes.h"

namespace XDTP {

extern void objectwrapper_null_destractor(void*);

class XDTPObjectWrapper
{
public:
	XDTPObjectWrapper();
	virtual ~XDTPObjectWrapper();

    /**
     * 末尾にオブジェクトを追加します。
     *
     * @param aType オブジェクトの種別
     * @param aValue オブジェクト
     */
    void add(int aType, const void* aValue);

    /**
     * オブジェクトを挿入します。
     *
     * @param aPos 位置 (aPos >= 0)
     * @param aType オブジェクトの種別
     * @param aValue オブジェクト
     */
    void insert(int aPos, int aType, const void* aValue);

    /**
     * 既存のオブジェクトを置き換えます。
     *
     * @param aPos 位置 (aPos >= 0)
     * @param aType オブジェクトの種別
     * @param aValue オブジェクト
     */
    void set(int aPos, int aType, const void* aValue);

    /**
     * オブジェクトを取得します。
     *
     * @param aPos 位置 (aPos >= 0)
     * @param aType オブジェクトの種別を格納する領域
     * @return オブジェクト
     */
    void* get(int aPos, int *aType = NULL) const;

    /**
     * オブジェクトを削除します。
     *
     * @param aPos 位置 (aPos >= 0)
     * @param bErase setDestractorにて設定済みの削除関数を使って自動的に
     *              削除する場合は true を指定します。
     */
    void erase(int aPos, bool bErase = true);

    /**
     * 全てのオブジェクトを削除します。
     *
     * @param bErase setDestractorにて設定済みの削除関数を使って自動的に
     *              削除する場合は true を指定します。
     */
    void clear(bool bErase = true);

    /**
     * 登録されているオブジェクトの総数を取得します。
     */
    int size() const;

public:
    /**
     * オブジェクトの削除関数を登録します。
     *
     * @param aType オブジェクトの種別
     * @param destractor 削除関数へのポインタ
     */
    static void setDestractor(int aType, void(*destractor)(void*));

private:
    IntVector       m_Types;
    PointerVector   m_Pointers;
};

};

#endif
