/* 
 * $Id: GLSDDocumentModule.h 23339 2010-01-29 12:32:18Z ozawa $
 *
 * Copyright 2005- ONGS Inc. All rights reserved.
 * 
 * author: Masanori OZAWA (ozawa@ongs.co.jp)
 * version: $Revision: 23339 $
 *
 * Redistribution and use in source and binary forms, with or without 
 * modification, are permitted provided that the following conditions
 * are met:
 * 
 *   1. Redistributions of source code must retain the above copyright
 *      notice, this list of conditions and the following disclaimer.
 *   2. Redistributions in binary form must reproduce the above copyright
 *      notice, this list of conditions and the following disclaimer in the
 *      documentation and/or other materials provided with the distribution.
 * 
 * THIS SOFTWARE IS PROVIDED BY ONGS INC ``AS IS'' AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL ONGS INC OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT,
 * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 * The views and conclusions contained in the software and documentation are
 * those of the authors and should not be interpreted as representing official
 * policies, either expressed or implied, of the ONGS Inc.
 * 
 */

#ifndef ___GLSDDOCUMENTMODULE_H
#define ___GLSDDOCUMENTMODULE_H

#include "modules/XDTPModuleAdapter.h"
#include "modules/imports/GLSDImportModule.h"
#include "modules/imports/ImportTextGLSD.h"

#include "libxml/tree.h"

namespace XDTP {

typedef std::list<GLSDImportModule*>    GLSDImportModuleList;

class GLSDDocumentModule : public XDTPModuleAdapter
{
public:
	GLSDDocumentModule();
	virtual ~GLSDDocumentModule();

    /**
     * 処理を開始する前に出力形式を設定します。
     * 
     * @param aType 出力形式
     */
    virtual void setOutputType(const Glib::ustring& aType);
    
    /**
     * 処理を開始する前にオプションを設定します。
     * 
     * @param anOptions オプション
     */
    virtual void setOption(const StringList& anOptions);

    /**
     * 処理を開始する前に出力ファイル名を設定します。
     * 
     * @param anOutputFile 出力ファイル名
     */
    virtual void setOutputFile(const Glib::ustring& anOutputFile);

    /**
     * 処理を開始する前に変換元XMLファイル名を設定します。
     * 
     * @param aXMLFile 変換元XMLファイル名
     */
    virtual void setXMLFile(const Glib::ustring& aXMLFile);
    
    /**
     * 入力ファイルのエンコードを指定します。
     * XMLファイルはこの限りではありません。
     * 
     * @param anInputEncoding 入力ファイルのエンコード
     */
    virtual void setInputEncoding(const Glib::ustring& anInputEncoding);

    /**
     * 出力ファイルのエンコードを指定します。
     * 
     * @param anOutputEncoding 出力ファイルのエンコード
     */
    virtual void setOutputEncoding(const Glib::ustring& anOutputEncoding);

    /**
     * 現在のXDTPTransformモジュールを指定します。
     * 
     * @param aXDTPTransform 現在のXDTPTransformモジュール
     */
    virtual void setXDTPTransform(const XDTPTransform *aXDTPTransform);

    /**
     * ファイルをparseする直前に呼び出されます。
     * 
     * @param aFile parse対象のファイル名
     */
    virtual void treatPreFile(const Glib::ustring& aFile);

    /**
     * parseしたXML文章をXSL変換する直前に呼び出されます。
     * 
     * @param aDocument XML文章
     */
    virtual void treatPreDocument(xmlDocPtr aDocument);

    /**
     * XSL変換後のXML文章を保存する直前に呼び出されます。
     * 
     * @param aDocument XML文章
     */
    virtual void treatPostDocument(xmlDocPtr aDocument);

    /**
     * XML文章を保存した直後に呼び出されます。
     * 
     * @param aFile 保存したファイル名
     */
    virtual void treatPostFile(const Glib::ustring& aFile);
    
protected:
    /**
     * importタグを標準化します。
     * 主に以下の処理を行います。<br>
     * <ul>
     *  <li>importタグの前後の不要なpタグを削除します。
     *  <li>importタグへのアンカーを作成します。
     * </ul>
     * 
     * @param aDocument
     *              変換対象DOMドキュメント
     */
    void normalizeImport(xmlDocPtr aDocument);

    /**
     * alias 置換マップを構築します。
     * 
     * @param aURL
     *              alias置換マップファイルへのURL
     * @param anOverWrite
     *              alias置換マップに同じキーが登録されていた場合に、
     *              値を上書きする場合は true を指定します。
     * @return 構築に成功した場合は true を指定します。
     */
    bool addAliasMap(const Glib::ustring& aURL, bool anOverWrite);

    /**
     * alias の置換処理を行います。
     * 
     * @param aDocument
     *              変換対象DOMドキュメント
     * @return 置換に成功した場合は true を戻します。
     */
    bool replaceAllAlias(xmlDocPtr aDocument);

protected:
    GLSDImportModuleList    m_ImportModules;
    ImportTextGLSD          m_ImportTextGLSD;
    String2StringMap        m_AliasMap;
};

};

#endif
