/* 
 * $Id: XDTPModuleAdapter.h 23339 2010-01-29 12:32:18Z ozawa $
 *
 * Copyright 2006- ONGS Inc. All rights reserved.
 * 
 * author: Masanori OZAWA (ozawa@ongs.co.jp)
 * version: $Revision: 23339 $
 *
 * Redistribution and use in source and binary forms, with or without 
 * modification, are permitted provided that the following conditions
 * are met:
 * 
 *   1. Redistributions of source code must retain the above copyright
 *      notice, this list of conditions and the following disclaimer.
 *   2. Redistributions in binary form must reproduce the above copyright
 *      notice, this list of conditions and the following disclaimer in the
 *      documentation and/or other materials provided with the distribution.
 * 
 * THIS SOFTWARE IS PROVIDED BY ONGS INC ``AS IS'' AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL ONGS INC OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT,
 * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 * The views and conclusions contained in the software and documentation are
 * those of the authors and should not be interpreted as representing official
 * policies, either expressed or implied, of the ONGS Inc.
 * 
 */
#ifndef ___XDTPMODULEADAPTER_H
#define ___XDTPMODULEADAPTER_H

#include "modules/XDTPModule.h"

namespace XDTP {

class XDTPModuleAdapter : public XDTPModule
{
public:
	virtual ~XDTPModuleAdapter();
    
    /**
     * 処理を開始する前に出力形式を設定します。
     * 変換処理を中断させるためにXDTP::Exceptionをthrowすることができます。
     * 
     * @param aType 出力形式
     */
    virtual void setOutputType(const Glib::ustring& aType);
    
    /**
     * 処理を開始する前にオプションを設定します。
     * 変換処理を中断させるためにXDTP::Exceptionをthrowすることができます。
     * 
     * @param anOptions オプション
     */
    virtual void setOption(const StringList& anOptions);

    /**
     * 処理を開始する前に出力ファイル名を設定します。
     * 変換処理を中断させるためにXDTP::Exceptionをthrowすることができます。
     * 
     * @param anOutputFile 出力ファイル名
     */
    virtual void setOutputFile(const Glib::ustring& anOutputFile);

    /**
     * 処理を開始する前に変換元XMLファイル名を設定します。
     * 変換処理を中断させるためにXDTP::Exceptionをthrowすることができます。
     * 
     * @param aXMLFile 変換元XMLファイル名
     */
    virtual void setXMLFile(const Glib::ustring& aXMLFile);
    
    /**
     * 入力ファイルのエンコードを指定します。
     * XMLファイルはこの限りではありません。
     * 変換処理を中断させるためにXDTP::Exceptionをthrowすることができます。
     * 
     * @param anInputEncoding 入力ファイルのエンコード
     */
    virtual void setInputEncoding(const Glib::ustring& anInputEncoding);

    /**
     * 出力ファイルのエンコードを指定します。
     * 変換処理を中断させるためにXDTP::Exceptionをthrowすることができます。
     * 
     * @param anOutputEncoding 出力ファイルのエンコード
     */
    virtual void setOutputEncoding(const Glib::ustring& anOutputEncoding);

    /**
     * 現在のXDTPTransformモジュールを指定します。
     * 
     * @param aXDTPTransform 現在のXDTPTransformモジュール
     */
    virtual void setXDTPTransform(const XDTPTransform *aXDTPTransform);

    /**
     * ファイルをparseする直前に呼び出されます。
     * 変換処理を中断させるためにXDTP::Exceptionをthrowすることができます。
     * 
     * @param aFile parse対象のファイル名
     */
    virtual void treatPreFile(const Glib::ustring& aFile);

    /**
     * parseしたXML文章をXSL変換する直前に呼び出されます。
     * 変換処理を中断させるためにXDTP::Exceptionをthrowすることができます。
     * 
     * @param aDocument XML文章
     */
    virtual void treatPreDocument(xmlDocPtr aDocument);

    /**
     * XSL変換後のXML文章を保存する直前に呼び出されます。
     * 変換処理を中断させるためにXDTP::Exceptionをthrowすることができます。
     * 
     * @param aDocument XML文章
     */
    virtual void treatPostDocument(xmlDocPtr aDocument);

    /**
     * XML文章を保存した直後に呼び出されます。
     * 変換処理を中断させるためにXDTP::Exceptionをthrowすることができます。
     * 
     * @param aFile 保存したファイル名
     */
    virtual void treatPostFile(const Glib::ustring& aFile);
    
protected:
    XDTPModuleAdapter();

    /**
     * 現在のXDTPTransformモジュールを取得します。
     * 
     * @return 現在のXDTPTransformモジュール
     */
    virtual const XDTPTransform * getXDTPTransform();

private:
    const XDTPTransform     *m_pXDTPTransform;
};

};

#endif
