/* 
 * $Id: XDTPModuleLoader.h 23339 2010-01-29 12:32:18Z ozawa $
 *
 * Copyright 2005- ONGS Inc. All rights reserved.
 * 
 * author: Masanori OZAWA (ozawa@ongs.co.jp)
 * version: $Revision: 23339 $
 *
 * Redistribution and use in source and binary forms, with or without 
 * modification, are permitted provided that the following conditions
 * are met:
 * 
 *   1. Redistributions of source code must retain the above copyright
 *      notice, this list of conditions and the following disclaimer.
 *   2. Redistributions in binary form must reproduce the above copyright
 *      notice, this list of conditions and the following disclaimer in the
 *      documentation and/or other materials provided with the distribution.
 * 
 * THIS SOFTWARE IS PROVIDED BY ONGS INC ``AS IS'' AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL ONGS INC OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT,
 * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 * The views and conclusions contained in the software and documentation are
 * those of the authors and should not be interpreted as representing official
 * policies, either expressed or implied, of the ONGS Inc.
 * 
 */

#ifndef ___XDTPMODULELOADER_H
#define ___XDTPMODULELOADER_H

#include "glibmm.h"
#include "modules/XDTPModule.h"
#include "modules/XDTPChecker.h"

namespace XDTP {

typedef struct {
    void*   handle;
    XDTPModule* (*buildModule)();
    XDTPChecker* (*buildChecker)();
    void (*freeModule)(XDTPModule*);
    void (*freeChecker)(XDTPChecker*);
    u_int32_t (*getModuleVersion)();
    std::list<XDTPModule*>  module;
    std::list<XDTPChecker*>  checker;
} XDTPModuleLibrary;

class XDTPModuleLoader
{
public:
	virtual ~XDTPModuleLoader();
    
    /**
     * XDTPModuleを内包するライブラリをロードします。
     * 
     * @param aPath XDTPModuleを内包するダイナミックリンクライブラリへのパス
     * @return XDTPModuleを内包するライブラリ。
     *         不要になった段階で、unloadModuleLibraryする必要があります。
     */
    static XDTPModuleLibrary* loadModuleLibrary(const Glib::ustring& aPath);
    
    /**
     * XDTPModuleを内包するライブラリを解放します。
     * 未解放のXDTPModule と XDTPCheckerが存在する場合は、これを解放します。
     * 
     * @param aLibrary XDTPModuleを内包するライブラリ。
     */
    static void unloadModuleLibrary(XDTPModuleLibrary* aLibrary);
    
    /**
     * XDTPModuleを構築します。
     * 
     * @param aLibrary XDTPModuleを内包するライブラリ。
     * @return XDTPModuleを戻します。不要になった段階で freeModule する必要があります。
     */
    static XDTPModule* buildModule(XDTPModuleLibrary* aLibrary);
    
    /**
     * XDTPCheckerを構築します。
     * 
     * @param aLibrary XDTPCheckerを内包するライブラリ。
     * @return XDTPCheckerを戻します。不要になった段階で freeChecker する必要があります。
     */
    static XDTPChecker* buildChecker(XDTPModuleLibrary* aLibrary);

    /**
     * XDTPModuleを解放します。
     * 
     * @param aLibrary XDTPModuleを内包するライブラリ。
     * @param aModule 構築したXDTPModule
     */
    static void freeModule(XDTPModuleLibrary* aLibrary, XDTPModule* aModule);
    
    /**
     * XDTPCheckerを解放します。
     * 
     * @param aLibrary XDTPCheckerを内包するライブラリ。
     * @param aModule 構築したXDTPChecker
     */
    static void freeChecker(XDTPModuleLibrary* aLibrary, XDTPChecker* aChecker);

private:
    XDTPModuleLoader();
};

};

#endif
