/* 
 * $Id: ImportTextGLSD.h 23339 2010-01-29 12:32:18Z ozawa $
 *
 * Copyright 2006- ONGS Inc. All rights reserved.
 * 
 * author: Masanori OZAWA (ozawa@ongs.co.jp)
 * version: $Revision: 23339 $
 *
 * Redistribution and use in source and binary forms, with or without 
 * modification, are permitted provided that the following conditions
 * are met:
 * 
 *   1. Redistributions of source code must retain the above copyright
 *      notice, this list of conditions and the following disclaimer.
 *   2. Redistributions in binary form must reproduce the above copyright
 *      notice, this list of conditions and the following disclaimer in the
 *      documentation and/or other materials provided with the distribution.
 * 
 * THIS SOFTWARE IS PROVIDED BY ONGS INC ``AS IS'' AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL ONGS INC OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT,
 * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 * The views and conclusions contained in the software and documentation are
 * those of the authors and should not be interpreted as representing official
 * policies, either expressed or implied, of the ONGS Inc.
 * 
 */

#ifndef ___IMPORTTEXTGLSD_H
#define ___IMPORTTEXTGLSD_H

#include "modules/imports/GLSDImportModuleAdapter.h"

namespace XDTP {

class ImportTextGLSD : public GLSDImportModuleAdapter
{
public:
	ImportTextGLSD();
	virtual ~ImportTextGLSD();

    /**
     * parseしたXML文章をXSL変換する直前に呼び出されます。
     * 
     * @param aDocument XML文章
     */
    virtual void treatPreDocument(xmlDocPtr aDocument);

protected:
    bool transform(xmlDocPtr aDocument, xmlNodePtr aNode);

private:
    bool glsdInclude(xmlDocPtr aDocument, xmlNodePtr aNode,
                      const Glib::ustring& aRef,
                      const Glib::ustring& aCaption,
                      const Glib::ustring& anEncoding);
    /**
     * import の相対参照を絶対参照に変換します。
     * 基準となる参照位置を元に、基準となる絶対的な参照位置を決定します。
     * 次に import タグ内の相対参照を、基準の絶対的な参照位置を元に修正します。
     * XDTPは file スキーマ以外で相対参照を認めないため、file スキーマ以外の
     * 相対参照は修正しません。
     * 
     * @param aRef
     *          基準となる参照位置
     * @param aDocument
     *          変換対象の import タグを保有するXMLドキュメント
     * @return 変換に成功した場合は true を戻します。
     */
    bool absoluteImportRef(const Glib::ustring& aRef, xmlDocPtr aDocument);

    /**
     * id 属性値を一意に識別できるよう正規化します。
     * 
     * @param aParent 元となるimportエレメント
     * @param aDocument
     *          変換対象の import タグを保有するXMLドキュメント
     * @return 変換に成功した場合は true を戻します。
     */
    bool normalizeImportID(xmlNodePtr aParent, xmlDocPtr aDocument);
};

};

#endif
