/* 
 * $Id: ImportTextSourcecode.h 23339 2010-01-29 12:32:18Z ozawa $
 *
 * Copyright 2005- ONGS Inc. All rights reserved.
 * 
 * author: Masanori OZAWA (ozawa@ongs.co.jp)
 * version: $Revision: 23339 $
 *
 * Redistribution and use in source and binary forms, with or without 
 * modification, are permitted provided that the following conditions
 * are met:
 * 
 *   1. Redistributions of source code must retain the above copyright
 *      notice, this list of conditions and the following disclaimer.
 *   2. Redistributions in binary form must reproduce the above copyright
 *      notice, this list of conditions and the following disclaimer in the
 *      documentation and/or other materials provided with the distribution.
 * 
 * THIS SOFTWARE IS PROVIDED BY ONGS INC ``AS IS'' AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL ONGS INC OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT,
 * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 * The views and conclusions contained in the software and documentation are
 * those of the authors and should not be interpreted as representing official
 * policies, either expressed or implied, of the ONGS Inc.
 * 
 */

#ifndef ___IMPORTTEXTSOURCECODE_H
#define ___IMPORTTEXTSOURCECODE_H

#include "modules/imports/GLSDImportModuleAdapter.h"

namespace XDTP {

class ImportTextSourcecode : public GLSDImportModuleAdapter
{
public:
	ImportTextSourcecode();
	virtual ~ImportTextSourcecode();

    /**
     * XSL変換後のXML文章を保存する直前に呼び出されます。
     * 
     * @param aDocument XML文章
     */
    virtual void treatPostDocument(xmlDocPtr aDocument);

    /**
     * XML文章を保存した直後に呼び出されます。
     * 
     * @param aFile 保存したファイル名
     */
    virtual void treatPostFile(const Glib::ustring& aFile);

protected:
    /**
     * ファイルからインポート処理対象の部分を抽出し、置換処理を
     * 行う際に呼び出されます。
     * 
     * @param aRef インポート先のファイル
     * @param aCaption キャプション
     * @param anEncoding インポート先のファイルのエンコード
     * @param aNewData 置換すべき文字列を応答します。
     * @return 処理結果を応答します。
     */
    virtual TIP_STATUS transformImportPointCallback
        (const Glib::ustring& aRef, const Glib::ustring& aCaption,
         const Glib::ustring& anEncoding, Glib::ustring& aNewData);

protected:
    bool transform(xmlDocPtr aDocument, xmlNodePtr aNode);

private:
    bool sourcecodeTo_nHTML(xmlDocPtr aDocument, xmlNodePtr aNode,
                            const Glib::ustring& aRef,
                            const Glib::ustring& aCaption,
                            const Glib::ustring& anEncoding);

private:
    bool m_needTIP;
};

};

#endif
