/*
 * $Id: xmlloader.h 20876 2009-04-12 20:04:59Z ozawa $
 *
 * Copyright 2005- ONGS Inc. All rights reserved.
 * 
 * author: Masanori OZAWA (ozawa@ongs.co.jp)
 * version: $Revision: 20876 $
 *
 * Redistribution and use in source and binary forms, with or without 
 * modification, are permitted provided that the following conditions
 * are met:
 * 
 *   1. Redistributions of source code must retain the above copyright
 *      notice, this list of conditions and the following disclaimer.
 *   2. Redistributions in binary form must reproduce the above copyright
 *      notice, this list of conditions and the following disclaimer in the
 *      documentation and/or other materials provided with the distribution.
 * 
 * THIS SOFTWARE IS PROVIDED BY ONGS INC ``AS IS'' AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL ONGS INC OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT,
 * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 * The views and conclusions contained in the software and documentation are
 * those of the authors and should not be interpreted as representing official
 * policies, either expressed or implied, of the ONGS Inc.
 * 
 */

#ifndef ___XMLLOADER_H
#define ___XMLLOADER_H

#include "libxml/parser.h"
#include "libxml/tree.h"

namespace XDTP {

class XMLLoader
{
protected:
    /**
     * コンストラクタ
     */
    XMLLoader();
    
    /**
     * デストラクタ
     */
    virtual ~XMLLoader();

public:
    /**
     * XMLをファイルから読み込みます。
     * 
     * @param aPath XMLファイル
     * @return XMLドキュメント。不要になった段階でxmlFreeDocする必要があります。
     */
    static xmlDocPtr load(const Glib::ustring& aPath);

    /**
     * XMLをメモリから読み込みます。
     * 
     * @param aBuffer バッファ（XML文字列）
     * @param aBytes バッファの長さ
     * @return XMLドキュメント。不要になった段階でxmlFreeDocする必要があります。
     */
    static xmlDocPtr loadMem(const char* aBuffer, int aBytes);

    /**
     * XMLをメモリから読み込みます。
     * 
     * @param aBuffer バッファ（XML文字列）
     * @return XMLドキュメント。不要になった段階でxmlFreeDocする必要があります。
     */
    static xmlDocPtr loadMem(const Glib::ustring& aBuffer);
};

};

#endif
