/*
 * $Id: xmlsaver.h 20876 2009-04-12 20:04:59Z ozawa $
 *
 * Copyright 2005- ONGS Inc. All rights reserved.
 * 
 * author: Masanori OZAWA (ozawa@ongs.co.jp)
 * version: $Revision: 20876 $
 *
 * Redistribution and use in source and binary forms, with or without 
 * modification, are permitted provided that the following conditions
 * are met:
 * 
 *   1. Redistributions of source code must retain the above copyright
 *      notice, this list of conditions and the following disclaimer.
 *   2. Redistributions in binary form must reproduce the above copyright
 *      notice, this list of conditions and the following disclaimer in the
 *      documentation and/or other materials provided with the distribution.
 * 
 * THIS SOFTWARE IS PROVIDED BY ONGS INC ``AS IS'' AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL ONGS INC OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT,
 * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 * The views and conclusions contained in the software and documentation are
 * those of the authors and should not be interpreted as representing official
 * policies, either expressed or implied, of the ONGS Inc.
 * 
 */

#ifndef ___XMLSAVER_H
#define ___XMLSAVER_H

#include "libxml/parser.h"
#include "libxml/tree.h"
#include "libxslt/xslt.h"
#include "libxslt/transform.h"

namespace XDTP {

class XMLSaver
{
protected:
    /**
     * コンストラクタ
     */
    XMLSaver();

    /**
     * デストラクタ
     */
    virtual ~XMLSaver();

public:
    /**
     * XMLをファイルに保存します。
     * 
     * @param aPath 出力先ファイル
     * @param aDocument XMLドキュメント
     * @param aXSL XSLT処理を行った場合は出力形式を保持するXSLドキュメント。
     *             処理を行っていない場合は NULL を指定する。
     * @param anEncoding 出力エンコード
     * @return 正常に保存した場合は true を戻す。
     */
    static bool save(const Glib::ustring& aPath, const xmlDocPtr aDocument,
                     const xsltStylesheetPtr aXSL, const Glib::ustring& anEncoding);

    /**
     * XMLを文字列に変換します。
     * 
     * @param aDocument XMLドキュメント
     * @param anEncoding 出力エンコード
     * @return 変換後の文字列。変換に失敗した場合は空文字列。
     */
    static std::string toString(const xmlDocPtr document, const Glib::ustring& anEncoding);
};

};

#endif
