<?xml version="1.0" encoding="EUC-JP"?>

<!--
 * $Id: DocumentModule.xsl 20876 2009-04-12 20:04:59Z ozawa $
 *
 * Copyright (c) 2003- ONGS Inc.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without 
 * modification, are permitted provided that the following conditions
 * are met:
 *
 *   1. Redistributions of source code must retain the above copyright
 *      notice, this list of conditions and the following disclaimer.
 *   2. Redistributions in binary form must reproduce the above copyright
 *      notice, this list of conditions and the following disclaimer in the
 *      documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY ONGS INC ``AS IS'' AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL ONGS INC OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT,
 * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 * The views and conclusions contained in the software and documentation are
 * those of the authors and should not be interpreted as representing official
 * policies, either expressed or implied, of the ONGS Inc.
-->

<xsl:stylesheet
 version="1.0"
 xmlns:xsl="http://www.w3.org/1999/XSL/Transform">

 <xsl:output method="text" encoding="EUC-JP" indent="no"/>

 <xsl:strip-space elements="/document"/>

<!-- ꥹȽ -->
 <xsl:template match="list" name="list">
  <xsl:param name="nestlevel" select="0"/>
  <xsl:choose>
   <xsl:when test='@type="itemize"'>
    <xsl:call-template name="itemize-item">
     <xsl:with-param name="nestlevel" select="$nestlevel"/>
    </xsl:call-template>
   </xsl:when>

   <xsl:when test='@type="order"'>
    <xsl:call-template name="order-item">
     <xsl:with-param name="nestlevel" select="$nestlevel"/>
    </xsl:call-template>
   </xsl:when>

   <xsl:otherwise>
    <xsl:call-template name="itemize-item">
     <xsl:with-param name="nestlevel" select="$nestlevel"/>
    </xsl:call-template>
   </xsl:otherwise>

  </xsl:choose>

  <xsl:if test="$nestlevel = 0">
   <!-- η泌Ȥ¸ߤϲԤ -->
   <xsl:for-each select="following-sibling::*[position()=1]">
    <xsl:call-template name="newline"/>
   </xsl:for-each>
  </xsl:if>
 </xsl:template>

 <xsl:template name="itemize-item">
  <xsl:param name="nestlevel" select="0"/>
  <xsl:for-each select="item/p | item/list">
   <xsl:choose>
    <xsl:when test='name() = "list"'>
     <xsl:call-template name="list">
      <xsl:with-param name="nestlevel" select="$nestlevel +1"/>
     </xsl:call-template>
    </xsl:when>
    <xsl:otherwise>
     <xsl:call-template name="indent-space">
      <xsl:with-param name="indent_len" select="$nestlevel"/>
     </xsl:call-template>
     <xsl:text></xsl:text><xsl:apply-templates/>
     <xsl:call-template name="newline"/>
    </xsl:otherwise>
   </xsl:choose>
  </xsl:for-each>
 </xsl:template>

 <xsl:template name="order-item">
  <xsl:param name="nestlevel" select="0"/>
  <xsl:for-each select="item/p | item/list">
   <xsl:choose>
    <xsl:when test='name() = "list"'>
     <xsl:call-template name="list">
      <xsl:with-param name="nestlevel" select="$nestlevel +1"/>
     </xsl:call-template>
    </xsl:when>
    <xsl:otherwise>
     <xsl:number level="multiple" format="1" from="docgroup" count='item'/>
     <xsl:text> </xsl:text><xsl:apply-templates/>
     <xsl:call-template name="newline"/>
    </xsl:otherwise>
   </xsl:choose>
  </xsl:for-each>
 </xsl:template>

 <xsl:template name="indent-space">
  <xsl:param name="indent_len"/>
  <xsl:choose>
   <xsl:when test="$indent_len = 0"/>
   <xsl:otherwise>
    <xsl:variable name="tmp_n" select="$indent_len -1"/>
    <xsl:text> </xsl:text>
    <xsl:call-template name="indent-space">
     <xsl:with-param name="indent_len" select="$tmp_n"/>
    </xsl:call-template>
   </xsl:otherwise>
  </xsl:choose>
 </xsl:template>

<!-- ʸν -->
 <xsl:template match="thebibliography">
  <xsl:text>ʸ</xsl:text><xsl:call-template name="newline"/>
  <xsl:call-template name="bibliography-item"/>
 </xsl:template>

 <xsl:template name="bibliography-item">
  <xsl:for-each select="bibitem">
   <xsl:text>[</xsl:text>
    <xsl:number level="any" count="bibitem"/>
   <xsl:text>] </xsl:text>
   <xsl:for-each select="author/p">
    <xsl:apply-templates/><xsl:text>, </xsl:text>
   </xsl:for-each>
   <i><xsl:for-each select="title[1]/p">
    <xsl:apply-templates/>
   </xsl:for-each></i>
   <xsl:for-each select="publisher/p">
    <xsl:text>, </xsl:text><xsl:apply-templates/>
   </xsl:for-each>
   <xsl:for-each select="year/p">
    <xsl:text>, </xsl:text><xsl:apply-templates/>
   </xsl:for-each>
   <xsl:call-template name="newline"/>
  </xsl:for-each>
 </xsl:template>


<!-- ν -->
 <xsl:template match="footnote">
  <xsl:text>(:</xsl:text><xsl:value-of select="."/><xsl:text>)</xsl:text>
 </xsl:template>


<!-- 󥫡ν -->
 <xsl:template match="access">
  <xsl:choose>

   <xsl:when test="starts-with(@ref,  'glsd:')">
    <xsl:variable name="target" select="substring-after(@ref, 'glsd:')"/>
    <xsl:for-each select="//*[@id = $target]">
     <xsl:call-template name="create_kind"/>
     <xsl:call-template name="create_number"/>
	</xsl:for-each>
	<xsl:value-of select="."/>
   </xsl:when>

   <xsl:otherwise>
	<xsl:value-of select="."/>
    <xsl:text>(</xsl:text><xsl:value-of select="@ref"/><xsl:text>)</xsl:text>
   </xsl:otherwise>

  </xsl:choose>
 </xsl:template>


<!-- ΰ̣ͭʸν -->
 <xsl:template match="mark">
  <xsl:value-of select="."/>
 </xsl:template>


<!-- ݡȤμ̤ -->
 <xsl:template name="create_kind">
  <xsl:choose>
   <xsl:when test="@type='text/csv'">ɽ</xsl:when>
   <xsl:when test="@type='text/xml'">ꥹ</xsl:when>
   <xsl:when test="@type='text/plain'">ƥ</xsl:when>
   <xsl:when test="@type='text/sourcecode'">ꥹ</xsl:when>
   <xsl:when test="@type='text/command-prompt'">ץץ</xsl:when>
   <xsl:when test="starts-with(@type, 'image/')"></xsl:when>
   <xsl:when test="name() = 'docgroup'"></xsl:when>
   <xsl:otherwise></xsl:otherwise>
  </xsl:choose>
 </xsl:template>

<!-- ݡȤΥʥХ󥰤Ԥ -->
 <xsl:template name="create_number">
  <xsl:variable name="startnumber" select="/document/docgroup/docinfo/initialnumber[1]/text()"/>
  <xsl:variable name="basenumber">
   <xsl:choose>
    <xsl:when test="name() = 'docgroup'">
     <xsl:number level="multiple" count="/document/docgroup//docgroup"/>
    </xsl:when>
    <xsl:otherwise>
     <xsl:number level="multiple" count="/document/docgroup//docgroup"/>.<xsl:number level="any" count="import" from="docgroup"/>
    </xsl:otherwise>
   </xsl:choose>
  </xsl:variable>

  <xsl:choose>
   <xsl:when test="1 &lt; $startnumber">
    <xsl:choose>
     <xsl:when test="0 &lt; string-length(substring-before($basenumber, '.'))">
      <xsl:value-of select="$startnumber -1 + number(substring-before($basenumber, '.'))"/><xsl:value-of select="concat('.', substring-after($basenumber, '.'))"/>
     </xsl:when>
     <xsl:otherwise>
      <xsl:value-of select="$startnumber -1 + number($basenumber)"/>
     </xsl:otherwise>
    </xsl:choose>
   </xsl:when>
   <xsl:otherwise>
    <xsl:value-of select="$basenumber"/>
   </xsl:otherwise>
  </xsl:choose>
 </xsl:template>

<!-- ǤդΥ⥸塼 -->
 <xsl:template match="p/import">
  <xsl:param name="kind">
   <xsl:call-template name="create_kind"/>
  </xsl:param>

  <xsl:param name="number"><xsl:call-template name="create_number"/></xsl:param>
  <import type="{@type}" ref="{@ref}" id="{@id}" encoding="{@encoding}"
   caption="{$kind}{$number} {@caption}"/>
 </xsl:template>

<!-- 겾̾ν -->
 <xsl:template match="ruby">
  <xsl:value-of select="."/><xsl:text>(</xsl:text><xsl:value-of select="@rubytext"/><xsl:text>)</xsl:text>
 </xsl:template>

 <xsl:template name="newline">
  <xsl:text>
</xsl:text>
 </xsl:template>

</xsl:stylesheet>
